@@ -161,6 +161,11 @@ void XmlStore::LoadThread::run()
         item.setDateTime(QDateTime::fromSecsSinceEpoch(dom.attribute("Time").toUInt()));
         item.setState(dom.attribute("State").toInt());
 
+        // do not load expired items
+        if (item.isExpired(TransferHistoryStore::getSettingsExpiryAge())) {
+            continue;
+        }
+
         Q_EMIT elementLoaded(i, total, item);
     }
     doc.clear();
@@ -190,6 +195,8 @@ XmlStore::~XmlStore()
         m_deleteThread->terminate();
     }
 
+    deleteExpiredItems();
+
     delete m_loadThread;
     delete m_saveThread;
     delete m_deleteThread;
@@ -246,3 +253,5 @@ void XmlStore::slotDeleteElement()
 
     Q_EMIT loadFinished();
 }
+
+#include "moc_transferhistorystore_xml_p.cpp"
